[pypy-svn] r15277 - pypy/dist/pypy/tool
rxe at codespeak.net
rxe at codespeak.net
Thu Jul 28 19:08:48 CEST 2005
Author: rxe
Date: Thu Jul 28 19:08:46 2005
New Revision: 15277
Modified:
pypy/dist/pypy/tool/traceop.py
Log:
Fix up to instantiate std object space ourselves.
Modified: pypy/dist/pypy/tool/traceop.py
==============================================================================
--- pypy/dist/pypy/tool/traceop.py (original)
+++ pypy/dist/pypy/tool/traceop.py Thu Jul 28 19:08:46 2005
@@ -365,16 +365,10 @@
if __name__ == '__main__':
- from pypy.objspace import trace
- from pypy.tool import option
- args = option.process_options(option.get_standard_options(),
- option.Options)
+ from pypy.objspace import std, trace
- # Create objspace...
- space = option.objspace()
-
- # Wrap up our space, with a trace space
- tspace = trace.create_trace_space(space)
+ # Wrap up std space, with a trace space
+ tspace = trace.create_trace_space(std.Space())
def func(x):
count = 0
More information about the Pypy-commit
mailing list